MiniWorldMaker
---------

<img align="right" src="miniworldmaker/resources/logo_big.png" alt="logo"/>
MiniWorldMaker allows you to create 2D mini worlds and games.



### Features

  * MiniWorldMaker supports pixel-based games as well as games with 
  tiles (e.g. Rogue-Likes)
  
  * Easy creation of animations
  
  * Music and sound effects
  
  * Integrated GUI elements like console for output, toolbar, ...
    
  * Load and Save to SQLite Databases
  
  * EXPERIMENTAL: Integrated Physics-Engine based on Pymunk
  
  * Open Source
  
  * Miniworldmaker is a 2D Engine based on Python 3 and pygame.

  * [Github](https://github.com/asbl/miniworldmaker) | [Documentation](http://miniworldmaker.de/) | [PyPi](https://pypi.org/project/miniworldmaker/)
